@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Plugin::AutoVersion::Relative::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Plugin::AutoVersion::Relative::VERSION = '0.02000000';
+  $Dist::Zilla::Plugin::AutoVersion::Relative::VERSION = '0.03000000';
 }
 
 # ABSTRACT: Time-Relative versioning
@@ -122,7 +122,7 @@ sub _build_relative {
         minor             => \( $self->minor ),
         relative          => \( $self->relative ),
         cldr              => sub { $self->_current_time->format_cldr( $_[0] ) },
-        days              => sub { ( ( ( $y * $MONTHS_IN_YEAR ) + $m ) * $DAYS_IN_MONTH ) + $d },
+        days              => sub { $self->_current_time->delta_days($self->_release_time)->in_units('days') },
         days_square       => sub { ( ( ( $y * $MONTHS_IN_YEAR ) + $m ) * $DAYS_IN_MONTH ) + $d },
         days_accurate     => sub { $self->_current_time->delta_days($self->_release_time)->in_units('days') },
         hours             => sub { $h },
@@ -149,7 +149,7 @@ Dist::Zilla::Plugin::AutoVersion::Relative - Time-Relative versioning
 
 =head1 VERSION
 
-version 0.02000000
+version 0.03000000
 
 =head1 SYNOPSIS
 
@@ -265,9 +265,9 @@ CLDR for the current time. See L<DateTime/format_cldr>
 
 =head2 days
 
-See L</days_square>
+See L</days_accurate>
 
-Will be L</days_accurate> in a future release.
+Used to use the algorithm as used in L</days_square> but uses the algorithm  in L</days_accurate> since 0.03000000
 
 =head2 days_square
 
@@ -276,7 +276,7 @@ An approximation of the number of days passed since milestone.
 Note that for this approximation, it is assumed all months are 31 days long, and years as such,
 have 372 days.
 
-This is a legacy way of computing dates that is to be superceded by days_accurate in a future release.
+This is a legacy way of computing dates, superceded by days_accurate since 0.03000000
 
 =head2 days_accurate
 
